@@ -5,11 +5,26 @@ use strict;
 
 Jifty::Action::Redirect - Redirect the browser
 
+=head1 SYNOPSIS
+
+  Jifty->web->new_action(
+      class => 'Redirect',
+      arguments => {
+          url => '/my/other/page',
+      },
+  )->run;
+
+=head1 DESCRIPTION
+
+Given a URL, this action forces Jifty to perform a redirect to thast URL after processing the rest of the request.
+
 =cut
 
 package Jifty::Action::Redirect;
 use base qw/Jifty::Action/;
 
+=head1 METHODS
+
 =head2 new
 
 By default, redirect actions happen as late as possible in the run
@@ -35,10 +50,9 @@ The only argument to redirect is the C<url> to redirect to.
 =cut
 
 sub arguments {
-        {
-            url => { constructor => 1 },
-        }
-
+    {
+        url => { constructor => 1 },
+    }
 }
 
 =head2 take_action
@@ -52,15 +66,32 @@ to inspect them.
 
 sub take_action {
     my $self = shift;
+
+    # Return now if the URL is not set
     return 1 unless ($self->argument_value('url'));
+
+    # Return now if the response is already sent (i.e., too late to redirect)
     return 0 unless Jifty->web->response->success;
 
+    # Find the URL to redirect to
     my $page = $self->argument_value('url');
 
+    # Set the next page and force the redirect
     Jifty->web->next_page($page);
     Jifty->web->force_redirect(1);
     return 1;
 }
 
+=head1 SEE ALSO
+
+L<Jifty::Action>, L<Jifty::Web/next_page>, L<Jity::Web/force_redirect>
+
+=head1 LICENSE
+
+Jifty is Copyright 2005-2007 Best Practical Solutions, LLC.
+Jifty is distributed under the same terms as Perl itself.
+
+=cut
+
 1;
 
