@@ -160,7 +160,7 @@ method name of your dispatcher class, or a fully qualified subroutine name.
 All wildcards in the C<$match> string becomes capturing regex patterns.  You
 can also pass in an array reference of matches, or a regex pattern.
 
-The C<$match> string may be qualified with a HTTP method name, such as
+The C<$match> string may be qualified with a HTTP method name or protocol, such as
 
 =over
 
@@ -176,6 +176,10 @@ The C<$match> string may be qualified with a HTTP method name, such as
 
 =item HEAD
 
+=item HTTPS
+
+=item HTTP
+
 =back
 
 =head2 on $match => $rule
@@ -263,6 +267,8 @@ our @EXPORT = qw<
 
     GET POST PUT HEAD DELETE OPTIONS
 
+    HTTPS HTTP
+
     plugin
 
     get next_rule last_rule
@@ -300,6 +306,9 @@ sub HEAD ($)    { _qualify method => @_ }
 sub DELETE ($)  { _qualify method => @_ }
 sub OPTIONS ($) { _qualify method => @_ }
 
+sub HTTPS ($)   { _qualify https  => @_ }
+sub HTTP ($)    { _qualify http   => @_ }
+
 sub plugin ($) { return { plugin => @_ } }
 
 our $CURRENT_STAGE;
@@ -929,6 +938,30 @@ sub _match_method {
     lc( $ENV{REQUEST_METHOD} ) eq lc($method);
 }
 
+=head2 _match_https
+
+Returns true if the current request is under SSL.
+
+=cut
+
+sub _match_https {
+    my $self = shift;
+    $self->log->debug("Matching request against HTTPS");
+    return exists $ENV{HTTPS} ? 1 : 0;
+}
+
+=head2 _match_http
+
+Returns true if the current request is not under SSL.
+
+=cut
+
+sub _match_http {
+    my $self = shift;
+    $self->log->debug("Matching request against HTTP");
+    return exists $ENV{HTTPS} ? 0 : 1;
+}
+
 sub _match_plugin {
     my ( $self, $plugin ) = @_;
     warn "Deferred check shouldn't happen";
@@ -1127,8 +1160,8 @@ sub template_exists {
     my $self     = shift;
     my $template = shift;
 
-    foreach my $handler ( Jifty->handler->_template_handlers) {
-        if ( Jifty->handler->$handler->template_exists($template) ) {
+    foreach my $handler ( Jifty->handler->view_handlers) {
+        if ( Jifty->handler->view($handler)->template_exists($template) ) {
             return 1;
         }
     }
@@ -1146,28 +1179,34 @@ HTML::Mason templates then the T::D template is used.
 =cut
 
 sub render_template {
-    my $self = shift;
+    my $self     = shift;
     my $template = shift;
-    my $showed = 0;
-    eval { 
-    	foreach my $handler (Jifty->handler->_template_handlers ) {
-        if (Jifty->handler->$handler->template_exists($template) ) {
-	   $showed = 1;
-            Jifty->handler->$handler->show($template);
-		last;
-        	}
-   	} 
-	if (not $showed and my $fallback_handler = Jifty->handler->_fallback_template_handler) {
-            Jifty->handler->$fallback_handler->show($template);
-	}
-    
+    my $showed   = 0;
+#    local $@;
+    eval {
+        foreach my $handler ( Jifty->handler->view_handlers ) {
+            if ( Jifty->handler->view($handler)->template_exists($template) ) {
+                $showed = 1;
+                Jifty->handler->view($handler)->show($template);
+                last;
+            }
+        }
+        if ( not $showed and my $fallback_handler = Jifty->handler->fallback_view_handler ) {
+            $fallback_handler->show($template);
+        }
+
     };
 
     my $err = $@;
 
     # Handle parse errors
+    $self->log->fatal("view class error: $err") if $err;
     if ( $err and not eval { $err->isa('HTML::Mason::Exception::Abort') } ) {
-
+        if ($template eq '/__jifty/error/mason_internal_error') {
+            $self->log->debug("can't render internal_error: $err");
+            $self->_abort;
+            return;
+        }
         # Save the request away, and redirect to an error page
         Jifty->web->response->error($err);
         my $c = Jifty::Continuation->new(
@@ -1176,12 +1215,9 @@ sub render_template {
             parent   => Jifty->web->request->continuation,
         );
 
-        warn "$err";
-
         # Redirect with a continuation
         Jifty->web->_redirect( "/__jifty/error/mason_internal_error?J:C=" . $c->id );
-    }
-    elsif ($err) {
+    } elsif ($err) {
         die $err;
     }
 
