@@ -7,7 +7,7 @@ Jifty->handle->log_sql_statements(1);
 
 =head1 NAME
 
-Jifty::Mason::Halo
+Jifty::Mason::Halo - Class for drawing "halos" around page components
 
 =head1 DESCRIPTION
 
@@ -56,7 +56,7 @@ sub start_component_hook {
         depth        => $DEPTH
     };
 
-    push @$INDEX_STACK, $#{@$STACK};
+    push @$INDEX_STACK, $#{$STACK};
     return if $self->_unrendered_component($context);
 
     $context->request->out(qq{<div id="halo-@{[$halo_base]}">});
