@@ -3,6 +3,10 @@ use strict;
 
 package Jifty::Server;
 
+=head1 NAME
+
+Jifty::Server - Stand-alone server implementation for Jifty
+
 =head1 SYNOPSIS
 
   use Jifty::Server;
@@ -17,8 +21,7 @@ creates a handy standalone web server for a lightweight Jifty application.
 =cut
 
 
-use base qw/HTTP::Server::Simple::CGI/;
-use base qw/Jifty::Object/;
+use base qw/HTTP::Server::Simple::CGI Jifty::Object/;
 use File::Spec;
 use Log::Log4perl;
 use HTTP::Server::Simple;
