@@ -2,6 +2,7 @@ use warnings;
 use strict;
 
 package Jifty::Web::Form::Clickable;
+use Class::Trigger;
 
 =head1 NAME
 
@@ -143,6 +144,8 @@ sub new {
         @_,
     );
 
+    $class->call_trigger('before_new', \%args);
+
     $args{render_as_button} = delete $args{as_button};
     $args{render_as_link}   = delete $args{as_link};
 
@@ -452,11 +455,25 @@ sub as_link {
           escape_label => $self->escape_label,
           url          => $self->complete_url,
           target       => $self->target,
+          continuation => $self->_continuation,
           @_ }
     );
     return $link;
 }
 
+sub _continuation {
+    # continuation info used by the update() call on client side
+    my $self = shift;
+    if ($self->call) {
+	return { 'type' => 'call', id => $self->call };
+    }
+    if ($self->returns) {
+	return { 'create' => $self->url };
+    }
+
+    return {};
+}
+
 =head2 as_button
 
 Returns the clickable as a L<Jifty::Web::Form::Field::InlineButton>,
@@ -473,6 +490,7 @@ sub as_button {
     my $field = Jifty::Web::Form::Field->new(
         { %$args,
           type => 'InlineButton',
+          continuation => $self->_continuation,
           @_ }
     );
     my %parameters = $self->post_parameters;
