@@ -5,6 +5,12 @@ package Jifty::Web::Form::Field::Unrendered;
 
 use base qw/Jifty::Web::Form::Field/;
 
+=head1 NAME
+
+Jifty::Web::Form::Field::Unrendered - Handle unrendered fields
+
+=head1 METHODS
+
 =head2 render
 
 Don't render anything. For one reason or another, this form field should never, ever be rendered, perhaps
@@ -18,4 +24,16 @@ sub render {
     '';
 }
 
+
+=head2 handler_allowed HANDLER_NAME
+
+Returns 1 if the handler (e.g. onclick) is allowed.  Undef otherwise.
+
+=cut
+
+sub handler_allowed {
+    undef;
+}
+
+
 1;
