@@ -28,11 +28,13 @@ sub render_widget {
     my $self  = shift;
     my $field = qq!<input type="file" name="@{[ $self->input_name ]}" !;
     $field .= $self->_widget_class();
-        $field .= qq!/>!;
+    $field .= $self->javascript;
+    $field .= qq!/>!;
     Jifty->web->out($field);
     '';
 }
 
+
 =head2 render_value
 
 The 'value', rendered, is empty so that BLOBs and the like don't get
@@ -44,4 +46,15 @@ sub render_value {
     '';
 }
 
+=head2 classes
+
+Add 'upload' to the rest of the classes
+
+=cut
+
+sub classes {
+    my $self = shift;
+    return join(' ', 'upload', ($self->SUPER::classes));
+}
+
 1;
