@@ -22,11 +22,10 @@ Sets up the fields of the message.
 
 sub setup {
     my $self = shift;
-    my $LoginUser = $self->LoginUserClass;
 
-    unless ( UNIVERSAL::isa($self->to, $LoginUser) ){
-    $self->log->error((ref $self) . " called with invalid user argument");
-    return;
+    unless ( UNIVERSAL::isa($self->to, $self->LoginUserClass) ){
+	$self->log->error((ref $self) . " called with invalid user argument");
+	return;
     }
 
     my $letme = Jifty::LetMe->new();
