@@ -79,6 +79,9 @@ Autocompleter.Base.prototype = {
   },
 
   show: function() {
+    /* Next line added by TRS, 07 July 2006 */
+    if ( this.options.beforeShow ) this.options.beforeShow(this);
+    
     if(Element.getStyle(this.update, 'display')=='none') this.options.onShow(this.element, this.update);
     if(!this.iefix && 
       (navigator.appVersion.indexOf('MSIE')>0) &&
@@ -101,6 +104,9 @@ Autocompleter.Base.prototype = {
   },
 
   hide: function() {
+    /* Next line added by TRS, 07 July 2006 */
+    if ( this.options.beforeHide ) this.options.beforeHide(this);
+    
     this.stopIndicator();
     if(Element.getStyle(this.update, 'display')!='none') this.options.onHide(this.element, this.update);
     if(this.iefix) Element.hide(this.iefix);
