@@ -1,12 +1,12 @@
 package Continuations::Dispatcher;
 use Jifty::Dispatcher -base;
 
-
+my $before = 0;
 before '/tutorial' => run {
     unless (Jifty->web->session->get('got_help')) {
         Jifty->web->tangent(url => '/index-help.html');
     }
-    set been_helped => 1;
+    set been_helped => ++$before;
 };
 
 on '/tutorial' => run {
@@ -17,6 +17,4 @@ before '/index-help.html' => run {
     Jifty->web->session->set(got_help => 1);
 };
 
-on '*' => show;
-
 1;
